You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2015/02/16 23:40:37 UTC

[67/82] [math] Update for next development iteration: commons-math4

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/RandomGeneratorFactory.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/RandomGeneratorFactory.java b/src/main/java/org/apache/commons/math4/random/RandomGeneratorFactory.java
index d4fb58a..401397a 100644
--- a/src/main/java/org/apache/commons/math4/random/RandomGeneratorFactory.java
+++ b/src/main/java/org/apache/commons/math4/random/RandomGeneratorFactory.java
@@ -14,10 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 import java.util.Random;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
 
 /**
  * Utilities for creating {@link RandomGenerator} instances.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/RandomVectorGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/RandomVectorGenerator.java b/src/main/java/org/apache/commons/math4/random/RandomVectorGenerator.java
index 26110c1..fc6ddec 100644
--- a/src/main/java/org/apache/commons/math4/random/RandomVectorGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/RandomVectorGenerator.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 
 /** This interface represents a random generator for whole vectors.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/SobolSequenceGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/SobolSequenceGenerator.java b/src/main/java/org/apache/commons/math4/random/SobolSequenceGenerator.java
index de16a7c..5fd89fc 100644
--- a/src/main/java/org/apache/commons/math4/random/SobolSequenceGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/SobolSequenceGenerator.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 import java.io.BufferedReader;
 import java.io.IOException;
@@ -25,12 +25,12 @@ import java.util.Arrays;
 import java.util.NoSuchElementException;
 import java.util.StringTokenizer;
 
-import org.apache.commons.math3.exception.MathInternalError;
-import org.apache.commons.math3.exception.MathParseException;
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.MathInternalError;
+import org.apache.commons.math4.exception.MathParseException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Implementation of a Sobol sequence.
@@ -65,7 +65,7 @@ public class SobolSequenceGenerator implements RandomVectorGenerator {
     private static final int MAX_DIMENSION = 1000;
 
     /** The resource containing the direction numbers. */
-    private static final String RESOURCE_NAME = "/assets/org/apache/commons/math3/random/new-joe-kuo-6.1000";
+    private static final String RESOURCE_NAME = "/assets/org/apache/commons/math4/random/new-joe-kuo-6.1000";
 
     /** Character set for file input. */
     private static final String FILE_CHARSET = "US-ASCII";

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/StableRandomGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/StableRandomGenerator.java b/src/main/java/org/apache/commons/math4/random/StableRandomGenerator.java
index 22a0da3..c8b0987 100644
--- a/src/main/java/org/apache/commons/math4/random/StableRandomGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/StableRandomGenerator.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * <p>This class provides a stable normalized random generator. It samples from a stable

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/SynchronizedRandomGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/SynchronizedRandomGenerator.java b/src/main/java/org/apache/commons/math4/random/SynchronizedRandomGenerator.java
index 4e79cb2..615f708 100644
--- a/src/main/java/org/apache/commons/math4/random/SynchronizedRandomGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/SynchronizedRandomGenerator.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 /**
  * Any {@link RandomGenerator} implementation can be thread-safe if it

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/UncorrelatedRandomVectorGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/UncorrelatedRandomVectorGenerator.java b/src/main/java/org/apache/commons/math4/random/UncorrelatedRandomVectorGenerator.java
index b573756..71bba9b 100644
--- a/src/main/java/org/apache/commons/math4/random/UncorrelatedRandomVectorGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/UncorrelatedRandomVectorGenerator.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 import java.util.Arrays;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
 
 /**
  * A {@link RandomVectorGenerator} that generates vectors with uncorrelated

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/UniformRandomGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/UniformRandomGenerator.java b/src/main/java/org/apache/commons/math4/random/UniformRandomGenerator.java
index 6a72eaa..6a2eb92 100644
--- a/src/main/java/org/apache/commons/math4/random/UniformRandomGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/UniformRandomGenerator.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * This class implements a normalized uniform random generator.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/UnitSphereRandomVectorGenerator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/UnitSphereRandomVectorGenerator.java b/src/main/java/org/apache/commons/math4/random/UnitSphereRandomVectorGenerator.java
index 12c7fad..9ac8ffe 100644
--- a/src/main/java/org/apache/commons/math4/random/UnitSphereRandomVectorGenerator.java
+++ b/src/main/java/org/apache/commons/math4/random/UnitSphereRandomVectorGenerator.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.util.FastMath;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/ValueServer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/ValueServer.java b/src/main/java/org/apache/commons/math4/random/ValueServer.java
index 975d2d8..a610783 100644
--- a/src/main/java/org/apache/commons/math4/random/ValueServer.java
+++ b/src/main/java/org/apache/commons/math4/random/ValueServer.java
@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.net.MalformedURLException;
 import java.net.URL;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.ZeroException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.ZeroException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Generates values for use in simulation applications.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/Well1024a.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/Well1024a.java b/src/main/java/org/apache/commons/math4/random/Well1024a.java
index 25420eb..6d96606 100644
--- a/src/main/java/org/apache/commons/math4/random/Well1024a.java
+++ b/src/main/java/org/apache/commons/math4/random/Well1024a.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 
 /** This class implements the WELL1024a pseudo-random number generator

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/Well19937a.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/Well19937a.java b/src/main/java/org/apache/commons/math4/random/Well19937a.java
index 0a24a18..d3abf95 100644
--- a/src/main/java/org/apache/commons/math4/random/Well19937a.java
+++ b/src/main/java/org/apache/commons/math4/random/Well19937a.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 
 /** This class implements the WELL19937a pseudo-random number generator

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/Well19937c.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/Well19937c.java b/src/main/java/org/apache/commons/math4/random/Well19937c.java
index ab52d4b..2adf075 100644
--- a/src/main/java/org/apache/commons/math4/random/Well19937c.java
+++ b/src/main/java/org/apache/commons/math4/random/Well19937c.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 
 /** This class implements the WELL19937c pseudo-random number generator

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/Well44497a.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/Well44497a.java b/src/main/java/org/apache/commons/math4/random/Well44497a.java
index 59543d2..52717e3 100644
--- a/src/main/java/org/apache/commons/math4/random/Well44497a.java
+++ b/src/main/java/org/apache/commons/math4/random/Well44497a.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 
 /** This class implements the WELL44497a pseudo-random number generator

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/Well44497b.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/Well44497b.java b/src/main/java/org/apache/commons/math4/random/Well44497b.java
index 4b50dbe..cc73f7f 100644
--- a/src/main/java/org/apache/commons/math4/random/Well44497b.java
+++ b/src/main/java/org/apache/commons/math4/random/Well44497b.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 
 /** This class implements the WELL44497b pseudo-random number generator

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/Well512a.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/random/Well512a.java b/src/main/java/org/apache/commons/math4/random/Well512a.java
index 1f15875..c68b9cd 100644
--- a/src/main/java/org/apache/commons/math4/random/Well512a.java
+++ b/src/main/java/org/apache/commons/math4/random/Well512a.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;
 
 
 /** This class implements the WELL512a pseudo-random number generator

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/random/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/special/BesselJ.java b/src/main/java/org/apache/commons/math4/special/BesselJ.java
index a2897a5..ad5eddc 100644
--- a/src/main/java/org/apache/commons/math4/special/BesselJ.java
+++ b/src/main/java/org/apache/commons/math4/special/BesselJ.java
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.special;
-
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.exception.ConvergenceException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.special.Gamma;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.MathArrays;
+package org.apache.commons.math4.special;
+
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.exception.ConvergenceException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.special.Gamma;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathArrays;
 
 /**
  * This class provides computation methods related to Bessel

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/special/Beta.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/special/Beta.java b/src/main/java/org/apache/commons/math4/special/Beta.java
index fc316e9..08a0d46 100644
--- a/src/main/java/org/apache/commons/math4/special/Beta.java
+++ b/src/main/java/org/apache/commons/math4/special/Beta.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.special;
+package org.apache.commons.math4.special;
 
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.util.ContinuedFraction;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.util.ContinuedFraction;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * <p>
@@ -109,7 +109,7 @@ public class Beta {
      * @param a Parameter {@code a}.
      * @param b Parameter {@code b}.
      * @return the regularized beta function I(x, a, b).
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x, double a, double b) {
@@ -128,7 +128,7 @@ public class Beta {
      * series is less than epsilon the approximation ceases to calculate
      * further elements in the series.
      * @return the regularized beta function I(x, a, b)
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x,
@@ -145,7 +145,7 @@ public class Beta {
      * @param b Parameter {@code b}.
      * @param maxIterations Maximum number of "iterations" to complete.
      * @return the regularized beta function I(x, a, b)
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x,
@@ -175,7 +175,7 @@ public class Beta {
      * further elements in the series.
      * @param maxIterations Maximum number of "iterations" to complete.
      * @return the regularized beta function I(x, a, b)
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x,

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/special/Erf.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/special/Erf.java b/src/main/java/org/apache/commons/math4/special/Erf.java
index a42a907..9872230 100644
--- a/src/main/java/org/apache/commons/math4/special/Erf.java
+++ b/src/main/java/org/apache/commons/math4/special/Erf.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.special;
+package org.apache.commons.math4.special;
 
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * This is a utility class that provides computation methods related to the
@@ -58,7 +58,7 @@ public class Erf {
      *
      * @param x the value.
      * @return the error function erf(x)
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      * @see Gamma#regularizedGammaP(double, double, double, int)
      */
@@ -88,7 +88,7 @@ public class Erf {
      *
      * @param x the value
      * @return the complementary error function erfc(x)
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      * @see Gamma#regularizedGammaQ(double, double, double, int)
      * @since 2.2

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/special/Gamma.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/special/Gamma.java b/src/main/java/org/apache/commons/math4/special/Gamma.java
index fef30e6..eb3fb5b 100644
--- a/src/main/java/org/apache/commons/math4/special/Gamma.java
+++ b/src/main/java/org/apache/commons/math4/special/Gamma.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.special;
+package org.apache.commons.math4.special;
 
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.util.ContinuedFraction;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.util.ContinuedFraction;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * <p>

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/special/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/special/package-info.java b/src/main/java/org/apache/commons/math4/special/package-info.java
index 6ebcbd5..f3289a9 100644
--- a/src/main/java/org/apache/commons/math4/special/package-info.java
+++ b/src/main/java/org/apache/commons/math4/special/package-info.java
@@ -17,4 +17,4 @@
 /**
  * Implementations of special functions such as Beta and Gamma.
  */
-package org.apache.commons.math3.special;
+package org.apache.commons.math4.special;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/Frequency.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/Frequency.java b/src/main/java/org/apache/commons/math4/stat/Frequency.java
index c9bc100..213f248 100644
--- a/src/main/java/org/apache/commons/math4/stat/Frequency.java
+++ b/src/main/java/org/apache/commons/math4/stat/Frequency.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat;
+package org.apache.commons.math4.stat;
 
 import java.io.Serializable;
 import java.text.NumberFormat;
@@ -27,10 +27,10 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.TreeMap;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.MathUtils;
 
 /**
  * Maintains a frequency distribution.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/StatUtils.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/clustering/package-info.java b/src/main/java/org/apache/commons/math4/stat/clustering/package-info.java
index f6b8d3e..bf59709 100644
--- a/src/main/java/org/apache/commons/math4/stat/clustering/package-info.java
+++ b/src/main/java/org/apache/commons/math4/stat/clustering/package-info.java
@@ -18,7 +18,7 @@
  * <h2>All classes and sub-packages of this package are deprecated.</h2>
  * <h3>Please use their replacements, to be found under
  *  <ul>
- *   <li>{@link org.apache.commons.math3.ml.clustering}</li>
+ *   <li>{@link org.apache.commons.math4.ml.clustering}</li>
  *  </ul>
  * </h3>
  *
@@ -26,4 +26,4 @@
  * Clustering algorithms.
  * </p>
  */
-package org.apache.commons.math3.stat.clustering;
+package org.apache.commons.math4.stat.clustering;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/correlation/Covariance.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/correlation/Covariance.java b/src/main/java/org/apache/commons/math4/stat/correlation/Covariance.java
index c462401..a42d435 100644
--- a/src/main/java/org/apache/commons/math4/stat/correlation/Covariance.java
+++ b/src/main/java/org/apache/commons/math4/stat/correlation/Covariance.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.correlation;
+package org.apache.commons.math4.stat.correlation;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.linear.BlockRealMatrix;
-import org.apache.commons.math3.stat.descriptive.moment.Mean;
-import org.apache.commons.math3.stat.descriptive.moment.Variance;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.linear.BlockRealMatrix;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.stat.descriptive.moment.Mean;
+import org.apache.commons.math4.stat.descriptive.moment.Variance;
 
 /**
  * Computes covariances for pairs of arrays or columns of a matrix.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/correlation/KendallsCorrelation.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/correlation/KendallsCorrelation.java b/src/main/java/org/apache/commons/math4/stat/correlation/KendallsCorrelation.java
index 5d66c5e..f71390d 100644
--- a/src/main/java/org/apache/commons/math4/stat/correlation/KendallsCorrelation.java
+++ b/src/main/java/org/apache/commons/math4/stat/correlation/KendallsCorrelation.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.correlation;
+package org.apache.commons.math4.stat.correlation;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.linear.BlockRealMatrix;
-import org.apache.commons.math3.linear.MatrixUtils;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Pair;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.linear.BlockRealMatrix;
+import org.apache.commons.math4.linear.MatrixUtils;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Pair;
 
 import java.util.Arrays;
 import java.util.Comparator;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/correlation/PearsonsCorrelation.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/correlation/PearsonsCorrelation.java b/src/main/java/org/apache/commons/math4/stat/correlation/PearsonsCorrelation.java
index 53d17ab..6059752 100644
--- a/src/main/java/org/apache/commons/math4/stat/correlation/PearsonsCorrelation.java
+++ b/src/main/java/org/apache/commons/math4/stat/correlation/PearsonsCorrelation.java
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.correlation;
+package org.apache.commons.math4.stat.correlation;
 
-import org.apache.commons.math3.distribution.TDistribution;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.linear.BlockRealMatrix;
-import org.apache.commons.math3.stat.regression.SimpleRegression;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.distribution.TDistribution;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.linear.BlockRealMatrix;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.stat.regression.SimpleRegression;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Computes Pearson's product-moment correlation coefficients for pairs of arrays
@@ -187,7 +187,7 @@ public class PearsonsCorrelation {
      * matrix must have been used to create this instance.</p>
      *
      * @return matrix of p-values
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if an error occurs estimating probabilities
      * @throws NullPointerException if this instance was created with no data
      */

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/correlation/SpearmansCorrelation.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/correlation/SpearmansCorrelation.java b/src/main/java/org/apache/commons/math4/stat/correlation/SpearmansCorrelation.java
index fbc80de..1afc940 100644
--- a/src/main/java/org/apache/commons/math4/stat/correlation/SpearmansCorrelation.java
+++ b/src/main/java/org/apache/commons/math4/stat/correlation/SpearmansCorrelation.java
@@ -15,21 +15,21 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.correlation;
+package org.apache.commons.math4.stat.correlation;
 
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.linear.BlockRealMatrix;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.stat.ranking.NaNStrategy;
-import org.apache.commons.math3.stat.ranking.NaturalRanking;
-import org.apache.commons.math3.stat.ranking.RankingAlgorithm;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.linear.BlockRealMatrix;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.stat.ranking.NaNStrategy;
+import org.apache.commons.math4.stat.ranking.NaturalRanking;
+import org.apache.commons.math4.stat.ranking.RankingAlgorithm;
 
 /**
  * Spearman's rank correlation. This implementation performs a rank

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/correlation/StorelessBivariateCovariance.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/correlation/StorelessBivariateCovariance.java b/src/main/java/org/apache/commons/math4/stat/correlation/StorelessBivariateCovariance.java
index 20722a6..93f6ca3 100644
--- a/src/main/java/org/apache/commons/math4/stat/correlation/StorelessBivariateCovariance.java
+++ b/src/main/java/org/apache/commons/math4/stat/correlation/StorelessBivariateCovariance.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.correlation;
+package org.apache.commons.math4.stat.correlation;
 
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Bivariate Covariance implementation that does not require input data to be

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/correlation/StorelessCovariance.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/correlation/StorelessCovariance.java b/src/main/java/org/apache/commons/math4/stat/correlation/StorelessCovariance.java
index 7e927ca..0d3b501 100644
--- a/src/main/java/org/apache/commons/math4/stat/correlation/StorelessCovariance.java
+++ b/src/main/java/org/apache/commons/math4/stat/correlation/StorelessCovariance.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.correlation;
+package org.apache.commons.math4.stat.correlation;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathUnsupportedOperationException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.linear.MatrixUtils;
-import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathUnsupportedOperationException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.linear.MatrixUtils;
+import org.apache.commons.math4.linear.RealMatrix;
 
 /**
  * Covariance implementation that does not require input data to be

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/correlation/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/correlation/package-info.java b/src/main/java/org/apache/commons/math4/stat/correlation/package-info.java
index adf285e..2d5ee30 100644
--- a/src/main/java/org/apache/commons/math4/stat/correlation/package-info.java
+++ b/src/main/java/org/apache/commons/math4/stat/correlation/package-info.java
@@ -19,4 +19,4 @@
  *        Correlations/Covariance computations.
  *
  */
-package org.apache.commons.math3.stat.correlation;
+package org.apache.commons.math4.stat.correlation;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractStorelessUnivariateStatistic.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractStorelessUnivariateStatistic.java b/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractStorelessUnivariateStatistic.java
index 4249994..fe46039 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractStorelessUnivariateStatistic.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractStorelessUnivariateStatistic.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.util.MathUtils;
-import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.MathUtils;
+import org.apache.commons.math4.util.Precision;
 
 /**
  *
@@ -53,7 +53,7 @@ public abstract class AbstractStorelessUnivariateStatistic
      * @param values input array
      * @return the value of the statistic applied to the input array
      * @throws MathIllegalArgumentException if values is null
-     * @see org.apache.commons.math3.stat.descriptive.UnivariateStatistic#evaluate(double[])
+     * @see org.apache.commons.math4.stat.descriptive.UnivariateStatistic#evaluate(double[])
      */
     @Override
     public double evaluate(final double[] values) throws MathIllegalArgumentException {
@@ -83,7 +83,7 @@ public abstract class AbstractStorelessUnivariateStatistic
      * @param length the number of elements to include
      * @return the value of the statistic applied to the included array entries
      * @throws MathIllegalArgumentException if the array is null or the indices are not valid
-     * @see org.apache.commons.math3.stat.descriptive.UnivariateStatistic#evaluate(double[], int, int)
+     * @see org.apache.commons.math4.stat.descriptive.UnivariateStatistic#evaluate(double[], int, int)
      */
     @Override
     public double evaluate(final double[] values, final int begin,
@@ -124,7 +124,7 @@ public abstract class AbstractStorelessUnivariateStatistic
      *
      * @param values values to add
      * @throws MathIllegalArgumentException if values is null
-     * @see org.apache.commons.math3.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[])
+     * @see org.apache.commons.math4.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[])
      */
     public void incrementAll(double[] values) throws MathIllegalArgumentException {
         if (values == null) {
@@ -143,7 +143,7 @@ public abstract class AbstractStorelessUnivariateStatistic
      * @param begin   index of the first array element to add
      * @param length  number of array elements to add
      * @throws MathIllegalArgumentException if values is null
-     * @see org.apache.commons.math3.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[], int, int)
+     * @see org.apache.commons.math4.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[], int, int)
      */
     public void incrementAll(double[] values, int begin, int length) throws MathIllegalArgumentException {
         if (test(values, begin, length)) {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractUnivariateStatistic.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractUnivariateStatistic.java b/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractUnivariateStatistic.java
index 9abe45a..c55d3f1 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractUnivariateStatistic.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/AbstractUnivariateStatistic.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.MathArrays;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.MathArrays;
 
 /**
  * Abstract base class for all implementations of the

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/AggregateSummaryStatistics.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/AggregateSummaryStatistics.java b/src/main/java/org/apache/commons/math4/stat/descriptive/AggregateSummaryStatistics.java
index ebc3e33..3a7c345 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/AggregateSummaryStatistics.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/AggregateSummaryStatistics.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.Iterator;
 
-import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math4.exception.NullArgumentException;
 
 /**
  * <p>

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/DescriptiveStatistics.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/DescriptiveStatistics.java b/src/main/java/org/apache/commons/math4/stat/descriptive/DescriptiveStatistics.java
index 31acd24..b1aa6d5 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/DescriptiveStatistics.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/DescriptiveStatistics.java
@@ -14,29 +14,29 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
 import java.io.Serializable;
 import java.lang.reflect.InvocationTargetException;
 import java.util.Arrays;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math3.stat.descriptive.moment.Kurtosis;
-import org.apache.commons.math3.stat.descriptive.moment.Mean;
-import org.apache.commons.math3.stat.descriptive.moment.Skewness;
-import org.apache.commons.math3.stat.descriptive.moment.Variance;
-import org.apache.commons.math3.stat.descriptive.rank.Max;
-import org.apache.commons.math3.stat.descriptive.rank.Min;
-import org.apache.commons.math3.stat.descriptive.rank.Percentile;
-import org.apache.commons.math3.stat.descriptive.summary.Sum;
-import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
-import org.apache.commons.math3.util.MathUtils;
-import org.apache.commons.math3.util.ResizableDoubleArray;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math4.stat.descriptive.moment.Kurtosis;
+import org.apache.commons.math4.stat.descriptive.moment.Mean;
+import org.apache.commons.math4.stat.descriptive.moment.Skewness;
+import org.apache.commons.math4.stat.descriptive.moment.Variance;
+import org.apache.commons.math4.stat.descriptive.rank.Max;
+import org.apache.commons.math4.stat.descriptive.rank.Min;
+import org.apache.commons.math4.stat.descriptive.rank.Percentile;
+import org.apache.commons.math4.stat.descriptive.summary.Sum;
+import org.apache.commons.math4.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathUtils;
+import org.apache.commons.math4.util.ResizableDoubleArray;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/MultivariateSummaryStatistics.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/MultivariateSummaryStatistics.java b/src/main/java/org/apache/commons/math4/stat/descriptive/MultivariateSummaryStatistics.java
index 3ede26e..f1db607 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/MultivariateSummaryStatistics.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/MultivariateSummaryStatistics.java
@@ -14,27 +14,27 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math3.stat.descriptive.moment.Mean;
-import org.apache.commons.math3.stat.descriptive.moment.VectorialCovariance;
-import org.apache.commons.math3.stat.descriptive.rank.Max;
-import org.apache.commons.math3.stat.descriptive.rank.Min;
-import org.apache.commons.math3.stat.descriptive.summary.Sum;
-import org.apache.commons.math3.stat.descriptive.summary.SumOfLogs;
-import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
-import org.apache.commons.math3.util.MathUtils;
-import org.apache.commons.math3.util.MathArrays;
-import org.apache.commons.math3.util.Precision;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math4.stat.descriptive.moment.Mean;
+import org.apache.commons.math4.stat.descriptive.moment.VectorialCovariance;
+import org.apache.commons.math4.stat.descriptive.rank.Max;
+import org.apache.commons.math4.stat.descriptive.rank.Min;
+import org.apache.commons.math4.stat.descriptive.summary.Sum;
+import org.apache.commons.math4.stat.descriptive.summary.SumOfLogs;
+import org.apache.commons.math4.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathArrays;
+import org.apache.commons.math4.util.MathUtils;
+import org.apache.commons.math4.util.Precision;
 
 /**
  * <p>Computes summary statistics for a stream of n-tuples added using the

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalMultivariateSummary.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalMultivariateSummary.java b/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalMultivariateSummary.java
index bfe4deb..64fa55f 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalMultivariateSummary.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalMultivariateSummary.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math4.linear.RealMatrix;
 
 /**
  *  Reporting interface for basic multivariate statistics.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummary.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummary.java b/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummary.java
index 2f310ac..e4b71ab 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummary.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummary.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
 /**
  *  Reporting interface for basic univariate statistics.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummaryValues.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummaryValues.java b/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummaryValues.java
index e216e9b..b7071c3 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummaryValues.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/StatisticalSummaryValues.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.MathUtils;
-import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathUtils;
+import org.apache.commons.math4.util.Precision;
 
 /**
  *  Value object representing the results of a univariate statistical summary.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/StorelessUnivariateStatistic.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/StorelessUnivariateStatistic.java b/src/main/java/org/apache/commons/math4/stat/descriptive/StorelessUnivariateStatistic.java
index e1c2464..4d72f38 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/StorelessUnivariateStatistic.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/StorelessUnivariateStatistic.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
 
 /**
  * Extends the definition of {@link UnivariateStatistic} with

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/SummaryStatistics.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/SummaryStatistics.java b/src/main/java/org/apache/commons/math4/stat/descriptive/SummaryStatistics.java
index 62fee80..3f0c4d7 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/SummaryStatistics.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/SummaryStatistics.java
@@ -14,25 +14,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math3.stat.descriptive.moment.Mean;
-import org.apache.commons.math3.stat.descriptive.moment.SecondMoment;
-import org.apache.commons.math3.stat.descriptive.moment.Variance;
-import org.apache.commons.math3.stat.descriptive.rank.Max;
-import org.apache.commons.math3.stat.descriptive.rank.Min;
-import org.apache.commons.math3.stat.descriptive.summary.Sum;
-import org.apache.commons.math3.stat.descriptive.summary.SumOfLogs;
-import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
-import org.apache.commons.math3.util.MathUtils;
-import org.apache.commons.math3.util.Precision;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math4.stat.descriptive.moment.Mean;
+import org.apache.commons.math4.stat.descriptive.moment.SecondMoment;
+import org.apache.commons.math4.stat.descriptive.moment.Variance;
+import org.apache.commons.math4.stat.descriptive.rank.Max;
+import org.apache.commons.math4.stat.descriptive.rank.Min;
+import org.apache.commons.math4.stat.descriptive.summary.Sum;
+import org.apache.commons.math4.stat.descriptive.summary.SumOfLogs;
+import org.apache.commons.math4.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathUtils;
+import org.apache.commons.math4.util.Precision;
 
 /**
  * <p>

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedDescriptiveStatistics.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedDescriptiveStatistics.java b/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedDescriptiveStatistics.java
index 270e4aa..9899f3a 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedDescriptiveStatistics.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedDescriptiveStatistics.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.util.MathUtils;
 
 /**
  * Implementation of
- * {@link org.apache.commons.math3.stat.descriptive.DescriptiveStatistics} that
+ * {@link org.apache.commons.math4.stat.descriptive.DescriptiveStatistics} that
  * is safe to use in a multithreaded environment.  Multiple threads can safely
  * operate on a single instance without causing runtime exceptions due to race
  * conditions.  In effect, this implementation makes modification and access

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java b/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java
index 889eb3a..05a92ce 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.linear.RealMatrix;
 
 /**
  * Implementation of
- * {@link org.apache.commons.math3.stat.descriptive.MultivariateSummaryStatistics} that
+ * {@link org.apache.commons.math4.stat.descriptive.MultivariateSummaryStatistics} that
  * is safe to use in a multithreaded environment.  Multiple threads can safely
  * operate on a single instance without causing runtime exceptions due to race
  * conditions.  In effect, this implementation makes modification and access

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedSummaryStatistics.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedSummaryStatistics.java b/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedSummaryStatistics.java
index 7eaf9ac..578d0c7 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedSummaryStatistics.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/SynchronizedSummaryStatistics.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.util.MathUtils;
 
 /**
  * Implementation of
- * {@link org.apache.commons.math3.stat.descriptive.SummaryStatistics} that
+ * {@link org.apache.commons.math4.stat.descriptive.SummaryStatistics} that
  * is safe to use in a multithreaded environment.  Multiple threads can safely
  * operate on a single instance without causing runtime exceptions due to race
  * conditions.  In effect, this implementation makes modification and access

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/UnivariateStatistic.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/UnivariateStatistic.java b/src/main/java/org/apache/commons/math4/stat/descriptive/UnivariateStatistic.java
index 5d6c9fe..4b831d5 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/UnivariateStatistic.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/UnivariateStatistic.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.util.MathArrays;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.util.MathArrays;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/descriptive/WeightedEvaluation.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/descriptive/WeightedEvaluation.java b/src/main/java/org/apache/commons/math4/stat/descriptive/WeightedEvaluation.java
index 01693dc..5bd512b 100644
--- a/src/main/java/org/apache/commons/math4/stat/descriptive/WeightedEvaluation.java
+++ b/src/main/java/org/apache/commons/math4/stat/descriptive/WeightedEvaluation.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.descriptive;
+package org.apache.commons.math4.stat.descriptive;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
 
 /**
  * Weighted evaluation for statistics.
diff --git a/src/main/java/org/apache/commons/math4/random/package-info.java b/src/main/java/org/apache/commons/math4/random/package-info.java
index 06e5739..4d42815 100644
--- a/src/main/java/org/apache/commons/math4/random/package-info.java
+++ b/src/main/java/org/apache/commons/math4/random/package-info.java
@@ -20,19 +20,19 @@
  *      <p>Commons-math provides a few pseudo random number generators. The top level interface is RandomGenerator.
  *      It is implemented by three classes:
  *      <ul>
- *        <li>{@link org.apache.commons.math3.random.JDKRandomGenerator JDKRandomGenerator}
+ *        <li>{@link org.apache.commons.math4.random.JDKRandomGenerator JDKRandomGenerator}
  *            that extends the JDK provided generator</li>
  *        <li>AbstractRandomGenerator as a helper for users generators</li>
  *        <li>BitStreamGenerator which is an abstract class for several generators and
  *            which in turn is extended by:
  *            <ul>
  *              <li>{@link org.apache.commons.math3.random.MersenneTwister MersenneTwister}</li>
  *              <li>{@link org.apache.commons.math3.random.Well512a Well512a}</li>
  *              <li>{@link org.apache.commons.math3.random.Well1024a Well1024a}</li>
  *              <li>{@link org.apache.commons.math3.random.Well19937a Well19937a}</li>
  *              <li>{@link org.apache.commons.math3.random.Well19937c Well19937c}</li>
  *              <li>{@link org.apache.commons.math3.random.Well44497a Well44497a}</li>
  *              <li>{@link org.apache.commons.math3.random.Well44497b Well44497b}</li>
  *            </ul>
  *          </li>
  *        </ul>
@@ -103,21 +103,21 @@
  *        <table border="1" align="center">
  *          <tr BGCOLOR="#CCCCFF"><td colspan="2"><font size="+2">Example of performances</font></td></tr>
  *          <tr BGCOLOR="#EEEEFF"><font size="+1"><td>Name</td><td>generation rate (relative to MersenneTwister)</td></font></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.MersenneTwister MersenneTwister}</td><td>1</td></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.JDKRandomGenerator JDKRandomGenerator}</td><td>between 0.96 and 1.16</td></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.Well512a Well512a}</td><td>between 0.85 and 0.88</td></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.Well1024a Well1024a}</td><td>between 0.63 and 0.73</td></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.Well19937a Well19937a}</td><td>between 0.70 and 0.71</td></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.Well19937c Well19937c}</td><td>between 0.57 and 0.71</td></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.Well44497a Well44497a}</td><td>between 0.69 and 0.71</td></tr>
  *          <tr><td>{@link org.apache.commons.math3.random.Well44497b Well44497b}</td><td>between 0.65 and 0.71</td></tr>
  *        </table>
  *      </p>
  *
  *      <p>
  *      So for most simulation problems, the better generators like {@link
  *      org.apache.commons.math3.random.Well19937c Well19937c} and {@link
  *      org.apache.commons.math3.random.Well44497b Well44497b} are probably very good choices.
  *      </p>
  *
  *      <p>
@@ -129,4 +129,4 @@
  *
  *
  */
-package org.apache.commons.math3.random;
+package org.apache.commons.math4.random;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/special/BesselJ.java
----------------------------------------------------------------------
@@ -20,19 +20,19 @@
  *            which in turn is extended by:
  *            <ul>
- *              <li>{@link org.apache.commons.math3.random.MersenneTwister MersenneTwister}</li>
- *              <li>{@link org.apache.commons.math3.random.Well512a Well512a}</li>
- *              <li>{@link org.apache.commons.math3.random.Well1024a Well1024a}</li>
- *              <li>{@link org.apache.commons.math3.random.Well19937a Well19937a}</li>
- *              <li>{@link org.apache.commons.math3.random.Well19937c Well19937c}</li>
- *              <li>{@link org.apache.commons.math3.random.Well44497a Well44497a}</li>
- *              <li>{@link org.apache.commons.math3.random.Well44497b Well44497b}</li>
+ *              <li>{@link org.apache.commons.math4.random.MersenneTwister MersenneTwister}</li>
+ *              <li>{@link org.apache.commons.math4.random.Well512a Well512a}</li>
+ *              <li>{@link org.apache.commons.math4.random.Well1024a Well1024a}</li>
+ *              <li>{@link org.apache.commons.math4.random.Well19937a Well19937a}</li>
+ *              <li>{@link org.apache.commons.math4.random.Well19937c Well19937c}</li>
+ *              <li>{@link org.apache.commons.math4.random.Well44497a Well44497a}</li>
+ *              <li>{@link org.apache.commons.math4.random.Well44497b Well44497b}</li>
  *            </ul>
  *          </li>
@@ -103,21 +103,21 @@
  *          <tr BGCOLOR="#CCCCFF"><td colspan="2"><font size="+2">Example of performances</font></td></tr>
  *          <tr BGCOLOR="#EEEEFF"><font size="+1"><td>Name</td><td>generation rate (relative to MersenneTwister)</td></font></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.MersenneTwister MersenneTwister}</td><td>1</td></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.JDKRandomGenerator JDKRandomGenerator}</td><td>between 0.96 and 1.16</td></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.Well512a Well512a}</td><td>between 0.85 and 0.88</td></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.Well1024a Well1024a}</td><td>between 0.63 and 0.73</td></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.Well19937a Well19937a}</td><td>between 0.70 and 0.71</td></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.Well19937c Well19937c}</td><td>between 0.57 and 0.71</td></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.Well44497a Well44497a}</td><td>between 0.69 and 0.71</td></tr>
- *          <tr><td>{@link org.apache.commons.math3.random.Well44497b Well44497b}</td><td>between 0.65 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.MersenneTwister MersenneTwister}</td><td>1</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.JDKRandomGenerator JDKRandomGenerator}</td><td>between 0.96 and 1.16</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.Well512a Well512a}</td><td>between 0.85 and 0.88</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.Well1024a Well1024a}</td><td>between 0.63 and 0.73</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.Well19937a Well19937a}</td><td>between 0.70 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.Well19937c Well19937c}</td><td>between 0.57 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.Well44497a Well44497a}</td><td>between 0.69 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math4.random.Well44497b Well44497b}</td><td>between 0.65 and 0.71</td></tr>
  *        </table>
  *      </p>
@@ -103,21 +103,21 @@
  *      <p>
  *      So for most simulation problems, the better generators like {@link
- *      org.apache.commons.math3.random.Well19937c Well19937c} and {@link
- *      org.apache.commons.math3.random.Well44497b Well44497b} are probably very good choices.
+ *      org.apache.commons.math4.random.Well19937c Well19937c} and {@link
+ *      org.apache.commons.math4.random.Well44497b Well44497b} are probably very good choices.
  *      </p>
  *
diff --git a/src/main/java/org/apache/commons/math4/stat/StatUtils.java b/src/main/java/org/apache/commons/math4/stat/StatUtils.java
index d7f9e53..4ecd49c 100644
--- a/src/main/java/org/apache/commons/math4/stat/StatUtils.java
+++ b/src/main/java/org/apache/commons/math4/stat/StatUtils.java
@@ -14,29 +14,29 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat;
+package org.apache.commons.math4.stat;
 
 import java.util.List;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.NoDataException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.stat.descriptive.DescriptiveStatistics;
-import org.apache.commons.math3.stat.descriptive.UnivariateStatistic;
-import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math3.stat.descriptive.moment.Mean;
-import org.apache.commons.math3.stat.descriptive.moment.Variance;
-import org.apache.commons.math3.stat.descriptive.rank.Max;
-import org.apache.commons.math3.stat.descriptive.rank.Min;
-import org.apache.commons.math3.stat.descriptive.rank.Percentile;
-import org.apache.commons.math3.stat.descriptive.summary.Product;
-import org.apache.commons.math3.stat.descriptive.summary.Sum;
-import org.apache.commons.math3.stat.descriptive.summary.SumOfLogs;
-import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NoDataException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.stat.descriptive.DescriptiveStatistics;
+import org.apache.commons.math4.stat.descriptive.UnivariateStatistic;
+import org.apache.commons.math4.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math4.stat.descriptive.moment.Mean;
+import org.apache.commons.math4.stat.descriptive.moment.Variance;
+import org.apache.commons.math4.stat.descriptive.rank.Max;
+import org.apache.commons.math4.stat.descriptive.rank.Min;
+import org.apache.commons.math4.stat.descriptive.rank.Percentile;
+import org.apache.commons.math4.stat.descriptive.summary.Product;
+import org.apache.commons.math4.stat.descriptive.summary.Sum;
+import org.apache.commons.math4.stat.descriptive.summary.SumOfLogs;
+import org.apache.commons.math4.stat.descriptive.summary.SumOfSquares;
 
 /**
  * StatUtils provides static methods for computing statistics based on data
@@ -191,7 +191,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.summary.SumOfLogs}.
+     * See {@link org.apache.commons.math4.stat.descriptive.summary.SumOfLogs}.
      * </p>
      *
      * @param values the input array
@@ -211,7 +211,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.summary.SumOfLogs}.
+     * See {@link org.apache.commons.math4.stat.descriptive.summary.SumOfLogs}.
      * </p>
      *
      * @param values the input array
@@ -233,7 +233,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -252,7 +252,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -273,7 +273,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.GeometricMean}
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.GeometricMean}
      * for details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -292,7 +292,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.GeometricMean}
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.GeometricMean}
      * for details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -316,7 +316,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[])} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -340,7 +340,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[], int, int)} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -369,7 +369,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[], double, int, int)} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -404,7 +404,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[], double)} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -431,7 +431,7 @@ public final class StatUtils {
      * population variance</a> of the entries in the input array, or
      * <code>Double.NaN</code> if the array is empty.
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the formula and computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -453,7 +453,7 @@ public final class StatUtils {
      * the input array, or <code>Double.NaN</code> if the designated subarray
      * is empty.
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -479,7 +479,7 @@ public final class StatUtils {
      * the input array, using the precomputed mean value.  Returns
      * <code>Double.NaN</code> if the designated subarray is empty.
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -511,7 +511,7 @@ public final class StatUtils {
      * precomputed mean value.  Returns <code>Double.NaN</code> if the array
      * is empty.
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -643,7 +643,7 @@ public final class StatUtils {
      * and less than or equal to 100)</li>
      * </ul></p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.rank.Percentile} for
      * a description of the percentile estimation algorithm used.</p>
      *
      * @param values input array of values
@@ -673,7 +673,7 @@ public final class StatUtils {
      * and less than or equal to 100)</li>
      * </ul></p>
      * <p>
      * See {@link org.apache.commons.math3.stat.descriptive.rank.Percentile} for
      * a description of the percentile estimation algorithm used.</p>
      *
      * @param values array of input values

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/clustering/Cluster.java
----------------------------------------------------------------------
@@ -233,7 +233,7 @@ public final class StatUtils {
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Mean} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
@@ -252,7 +252,7 @@ public final class StatUtils {
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Mean} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
@@ -316,7 +316,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -340,7 +340,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -369,7 +369,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -404,7 +404,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -431,7 +431,7 @@ public final class StatUtils {
      * <code>Double.NaN</code> if the array is empty.
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the formula and computing algorithm.</p>
      * <p>
@@ -453,7 +453,7 @@ public final class StatUtils {
      * is empty.
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -479,7 +479,7 @@ public final class StatUtils {
      * <code>Double.NaN</code> if the designated subarray is empty.
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -511,7 +511,7 @@ public final class StatUtils {
      * is empty.
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math4.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -643,7 +643,7 @@ public final class StatUtils {
      * </ul></p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.rank.Percentile} for
+     * See {@link org.apache.commons.math4.stat.descriptive.rank.Percentile} for
      * a description of the percentile estimation algorithm used.</p>
      *
@@ -673,7 +673,7 @@ public final class StatUtils {
      * </ul></p>
      * <p>
-     * See {@link org.apache.commons.math3.stat.descriptive.rank.Percentile} for
+     * See {@link org.apache.commons.math4.stat.descriptive.rank.Percentile} for
      * a description of the percentile estimation algorithm used.</p>
      *
diff --git a/src/main/java/org/apache/commons/math4/stat/clustering/Cluster.java b/src/main/java/org/apache/commons/math4/stat/clustering/Cluster.java
index 8d9483e..3fbc11b 100644
--- a/src/main/java/org/apache/commons/math4/stat/clustering/Cluster.java
+++ b/src/main/java/org/apache/commons/math4/stat/clustering/Cluster.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.clustering;
+package org.apache.commons.math4.stat.clustering;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -26,7 +26,7 @@ import java.util.List;
  * @param <T> the type of points that can be clustered
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
  * use {@link org.apache.commons.math3.ml.clustering.Cluster} instead
  */
 @Deprecated
 public class Cluster<T extends Clusterable<T>> implements Serializable {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/clustering/Clusterable.java
----------------------------------------------------------------------
@@ -26,7 +26,7 @@ import java.util.List;
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
- * use {@link org.apache.commons.math3.ml.clustering.Cluster} instead
+ * use {@link org.apache.commons.math4.ml.clustering.Cluster} instead
  */
 @Deprecated
diff --git a/src/main/java/org/apache/commons/math4/stat/clustering/Clusterable.java b/src/main/java/org/apache/commons/math4/stat/clustering/Clusterable.java
index f9818f3..f9f75b4 100644
--- a/src/main/java/org/apache/commons/math4/stat/clustering/Clusterable.java
+++ b/src/main/java/org/apache/commons/math4/stat/clustering/Clusterable.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.clustering;
+package org.apache.commons.math4.stat.clustering;
 
 import java.util.Collection;
 
@@ -24,7 +24,7 @@ import java.util.Collection;
  * @param <T> the type of point that can be clustered
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
  * use {@link org.apache.commons.math3.ml.clustering.Clusterable} instead
  */
 @Deprecated
 public interface Clusterable<T> {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/clustering/DBSCANClusterer.java
----------------------------------------------------------------------
@@ -24,7 +24,7 @@ import java.util.Collection;
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
- * use {@link org.apache.commons.math3.ml.clustering.Clusterable} instead
+ * use {@link org.apache.commons.math4.ml.clustering.Clusterable} instead
  */
 @Deprecated
diff --git a/src/main/java/org/apache/commons/math4/stat/clustering/DBSCANClusterer.java b/src/main/java/org/apache/commons/math4/stat/clustering/DBSCANClusterer.java
index 13247eb..0122f48 100644
--- a/src/main/java/org/apache/commons/math4/stat/clustering/DBSCANClusterer.java
+++ b/src/main/java/org/apache/commons/math4/stat/clustering/DBSCANClusterer.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.clustering;
+package org.apache.commons.math4.stat.clustering;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -24,9 +24,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.util.MathUtils;
 
 /**
  * DBSCAN (density-based spatial clustering of applications with noise) algorithm.
@@ -57,7 +57,7 @@ import org.apache.commons.math3.util.MathUtils;
  * A Density-Based Algorithm for Discovering Clusters in Large Spatial Databases with Noise</a>
  * @since 3.1
  * @deprecated As of 3.2 (to be removed in 4.0),
  * use {@link org.apache.commons.math3.ml.clustering.DBSCANClusterer} instead
  */
 @Deprecated
 public class DBSCANClusterer<T extends Clusterable<T>> {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanDoublePoint.java
----------------------------------------------------------------------
@@ -57,7 +57,7 @@ import org.apache.commons.math3.util.MathUtils;
  * @since 3.1
  * @deprecated As of 3.2 (to be removed in 4.0),
- * use {@link org.apache.commons.math3.ml.clustering.DBSCANClusterer} instead
+ * use {@link org.apache.commons.math4.ml.clustering.DBSCANClusterer} instead
  */
 @Deprecated
diff --git a/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanDoublePoint.java b/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanDoublePoint.java
index 32c236c..912b01d 100644
--- a/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanDoublePoint.java
+++ b/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanDoublePoint.java
@@ -14,19 +14,19 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.clustering;
+package org.apache.commons.math4.stat.clustering;
 
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.Arrays;
 
-import org.apache.commons.math3.util.MathArrays;
+import org.apache.commons.math4.util.MathArrays;
 
 /**
  * A simple implementation of {@link Clusterable} for points with double coordinates.
  * @since 3.1
  * @deprecated As of 3.2 (to be removed in 4.0),
  * use {@link org.apache.commons.math3.ml.clustering.DoublePoint} instead
  */
 @Deprecated
 public class EuclideanDoublePoint implements Clusterable<EuclideanDoublePoint>, Serializable {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanIntegerPoint.java
----------------------------------------------------------------------
@@ -14,19 +14,19 @@
  * @since 3.1
  * @deprecated As of 3.2 (to be removed in 4.0),
- * use {@link org.apache.commons.math3.ml.clustering.DoublePoint} instead
+ * use {@link org.apache.commons.math4.ml.clustering.DoublePoint} instead
  */
 @Deprecated
diff --git a/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanIntegerPoint.java b/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanIntegerPoint.java
index 508b0fa..bbc707e 100644
--- a/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanIntegerPoint.java
+++ b/src/main/java/org/apache/commons/math4/stat/clustering/EuclideanIntegerPoint.java
@@ -15,19 +15,19 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.clustering;
+package org.apache.commons.math4.stat.clustering;
 
 import java.io.Serializable;
 import java.util.Arrays;
 import java.util.Collection;
 
-import org.apache.commons.math3.util.MathArrays;
+import org.apache.commons.math4.util.MathArrays;
 
 /**
  * A simple implementation of {@link Clusterable} for points with integer coordinates.
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
  * use {@link org.apache.commons.math3.ml.clustering.DoublePoint} instead
  */
 @Deprecated
 public class EuclideanIntegerPoint implements Clusterable<EuclideanIntegerPoint>, Serializable {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/clustering/KMeansPlusPlusClusterer.java
----------------------------------------------------------------------
@@ -15,19 +15,19 @@
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
- * use {@link org.apache.commons.math3.ml.clustering.DoublePoint} instead
+ * use {@link org.apache.commons.math4.ml.clustering.DoublePoint} instead
  */
 @Deprecated
diff --git a/src/main/java/org/apache/commons/math4/stat/clustering/KMeansPlusPlusClusterer.java b/src/main/java/org/apache/commons/math4/stat/clustering/KMeansPlusPlusClusterer.java
index ace584e..6c93ed5 100644
--- a/src/main/java/org/apache/commons/math4/stat/clustering/KMeansPlusPlusClusterer.java
+++ b/src/main/java/org/apache/commons/math4/stat/clustering/KMeansPlusPlusClusterer.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.clustering;
+package org.apache.commons.math4.stat.clustering;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -23,12 +23,12 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Random;
 
-import org.apache.commons.math3.exception.ConvergenceException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.stat.descriptive.moment.Variance;
-import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math4.exception.ConvergenceException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.stat.descriptive.moment.Variance;
+import org.apache.commons.math4.util.MathUtils;
 
 /**
  * Clustering algorithm based on David Arthur and Sergei Vassilvitski k-means++ algorithm.
@@ -36,7 +36,7 @@ import org.apache.commons.math3.util.MathUtils;
  * @see <a href="http://en.wikipedia.org/wiki/K-means%2B%2B">K-means++ (wikipedia)</a>
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
  * use {@link org.apache.commons.math3.ml.clustering.KMeansPlusPlusClusterer} instead
  */
 @Deprecated
 public class KMeansPlusPlusClusterer<T extends Clusterable<T>> {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/clustering/package-info.java
----------------------------------------------------------------------
@@ -36,7 +36,7 @@ import org.apache.commons.math3.util.MathUtils;
  * @since 2.0
  * @deprecated As of 3.2 (to be removed in 4.0),
- * use {@link org.apache.commons.math3.ml.clustering.KMeansPlusPlusClusterer} instead
+ * use {@link org.apache.commons.math4.ml.clustering.KMeansPlusPlusClusterer} instead
  */
 @Deprecated